import setuptools

setuptools.setup(
	name='Quelert2',
	version='2.0.1',
	author='Georgy2008',
	author_email='zadvornow2908@gmail.com',
	description='Ql2',
	packages=['q'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)